/*
 ATtiny1634 Test
 Version: 1.0
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 27/05/2014
 Last Modified: 27/05/2014
  
 */
 
#ifndef cbi
#define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
#endif
#ifndef sbi
#define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
#endif

#ifndef NULL
#define NULL ((void *)0)
#endif

#define LOW 0
#define HIGH 1
#define false 0
#define true 1

#define T16MS 0
#define T32MS 1
#define T64MS 2
#define T128MS 3
#define T250MS 4
#define T500MS 5
#define T1S 6
#define T2S 7
#define T4S 8
#define T8S 9

// Sleep
void system_sleep(void) {
	set_sleep_mode(SLEEP_MODE_PWR_DOWN); // Set sleep mode
	sleep_mode(); // System sleeps here
}

// Watchdog timeout values
// 0=16ms, 1=32ms, 2=64ms, 3=128ms, 4=250ms, 5=500ms, 6=1sec, 7=2sec, 8=4sec, 9=8sec
// Modified for ATtiny1634
void setup_watchdog(uint8_t ii) {
	uint8_t bb;
	if (ii > 9 ) ii=9;
	bb=ii & 7;
	if (ii > 7) bb|= (1<<5);
	
	MCUSR &= ~(1<<WDRF);
	// Write correct signature to CCP
	CCP = 0xD8;
	// Set new watchdog timeout value
	WDTCSR = bb;
	// Start timed sequence
	WDTCSR |= (1<<WDE) | (1<<WDIE);
}

// Turn off the watchdog
void turnOffwatchdog(void) {
	cli(); // Turn interrupts off
	MCUSR &= ~(1<<WDRF);
	// Write correct signature to CCP
	CCP = 0xD8;
	// Turn off watchdog
	WDTCSR = 0;
	sei(); // Turn interrupts back on
}

// Watchdog sleep function - combines all the above functions into one
void watchdog_sleep(int timeout) { 
	setup_watchdog(timeout);
	system_sleep();
	turnOffwatchdog();
}

// Setup the ATtiny
void setup(void) {
	
	// Set outputs
	DDRB |= (1<<LED);
	
	sei(); // Turn on interrupts
}
